"""Forney-style (aka Normal Factor Graph, aka Edge Varaible) graphical models.

Contains model definition and algorithms specific to it.
"""
from .nfg_model import NormalFactorGraphModel
